% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CST_RegimesAssign.R
\name{RegimesAssign}
\alias{RegimesAssign}
\title{Function for matching a field of anomalies with 
a set of maps used as a reference (e.g. clusters obtained from the WeatherRegime function).}
\usage{
RegimesAssign(
  data,
  ref_maps,
  lat,
  method = "distance",
  composite = FALSE,
  ncores = NULL
)
}
\arguments{
\item{data}{an array containing anomalies with named dimensions: dataset, member, sdate, ftime, lat and lon.}

\item{ref_maps}{Array with 3-dimensions (lon,lat, k) containing the maps  k=1,..,n maps that will be used as a reference for the matching.}

\item{lat}{Vector of latitudes.}

\item{method}{Whether the matching will be performed in terms of minimum distance (default=’distance’) or 
the maximum spatial correlation (method=’ACC’) between the maps.}

\item{composite}{a logical indicating if the composite maps are computed or not.}

\item{ncores}{The number of multicore threads to use for parallel computation.}
}
\value{
A list with elements \code{$composite} (3-d array (lon, lat, k) containing the composites k=1,..,K for case (*1)
        \code{$pvalue} (3-d array (lon,lat, k) containing the pvalue of the composites obtained through a t-test 
        that accounts for the serial dependence of the data with the same structure as Composite.),
        \code{$cluster} (array with the same dimensions that data except latitude and longitude indicating the regime.maps to which each point is allocated.) ,
        \code{$frequency} (A vector of integers (from k=1,...k n reference maps) indicating the percentage of assignations corresponding to each map.),
}
\description{
This function performs the matching between a field of anomalies and a set
of maps which will be used as a reference. The anomalies will be assigned to the reference map 
for which the minimum Eucledian distance (method=’distance’) or highest spatial correlation 
(method=‘ACC’) is obtained.
}
\examples{
regimes <- WeatherRegime(data = lonlat_data$obs$data, lat=lonlat_data$obs$lat, EOFS = FALSE, ncenters = 4)$composite
maps_ref <- Subset(regimes, along=c('dataset','member'), indices=list(1,1),drop='selected')
res1 <- RegimesAssign(data=lonlat_data$exp$data, ref_maps = maps_ref, 
lat=lonlat_data$exp$lat,composite=FALSE)
}
\references{
Torralba, V. (2019) Seasonal climate prediction for the wind energy sector: methods and tools for the development of a climate service. Thesis. Available online: \url{https://eprints.ucm.es/56841/}
}
\author{
Verónica Torralba - BSC, \email{veronica.torralba@bsc.es}
}
